from notifier.slack import SlackMsgSend


class Message:
    def __init__(self, postman=None, **kwargs):
        self._postman = postman
        self._msgs = []

    def write(self, msg):
        self._msgs.append(msg)

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self._postman('\n'.join(self._msgs))


class SlackMessage(Message):
    def __init__(self, postman=None, **kwargs):
        super().__init__()

        if postman is not None:
            if isinstance(postman, SlackMsgSend):
                self._postman = postman
            else:
                raise RuntimeError('When using class SlackPostmanMixin, you should provide SlackMsgSend instance as a postman')
        else:
            self._postman = SlackMsgSend(**kwargs)



import os
# Use the package we installed
from slack_bolt import App
from slack_bolt.adapter.socket_mode import SocketModeHandler

# Initializes your app with your bot token and signing secret
app = App(
        token=os.environ.get("SLACK_BOT_TOKEN"),
    )


@app.command("/hello-socket-mode")
def hello_command(ack, body):
    user_id = body["user_id"]
    ack(f"Hi, <@{user_id}>!")


@app.event("app_mention")
def event_test(say):
    say("Hi there!")

if __name__ == "__main__":
    SocketModeHandler(app, os.environ["SLACK_APP_TOKEN"]).start()



import logging
import os
from pathlib import Path
from slack_sdk import WebClient
from slack_sdk.errors import SlackApiError


logger = logging.getLogger(__name__)

def get_slack_bot_token(token_var=None, token_file=None, **kwargs):
    os.environ.get("SLACK_BOT_TOKEN")
    SLACK_BOT_TOKEN_FILENAME = Path('.slack_bot_token')
    if SLACK_BOT_TOKEN_FILENAME.is_file() and token_file is None:  # in current working directory
        token_file = SLACK_BOT_TOKEN_FILENAME
    token_file = token_file if token_file is not  None \
            else Path(os.environ['HOME'])  / SLACK_BOT_TOKEN_FILENAME
    if token_file.is_file():
        with open(token_file, 'rt') as r:
            return r.read().strip()
    else:
        logger.warn(f'{token_file} file does not exists.\nCannot use safer way of loading tokens from file for slack bot token.')
        token_var = token_var if token_var is not None else 'SLACK_BOT_TOKEN'
        logger.warn(f'Loading slack bot token from {token_var} variable.')
        return os.environ[token_var].strip()


def send_msg_to_channel(token, channel, text):
    client = WebClient(token=token)
    logger = logging.getLogger(__name__)

    try:
        result = client.chat_postMessage(
            channel=channel,
            text=text
        )
        logger.info(result)
    except SlackApiError as e:
        logger.error(f"Error posting message: {e}")


class SlackMsgSend:
    def __init__(self, msg=None, channel=None, token=None, **kwargs):
        self.channel = "" if channel is None else channel
        self.msg = "" if msg is None else msg
        self.token = get_slack_bot_token() if token is None else token
        assert self.channel, 'You need to specify channel'
        assert self.token, 'You need to specify token'

    def __call__(self, msg=None, append=True):
        msg = "" if msg is None else msg
        if append:
            self.msg += msg
        else:
            self.msg = msg
        send_msg_to_channel(self.token, self.channel, self.msg)



#!/usr/bin/env python3
import logging
import os
from slack_sdk import WebClient
from slack_sdk.errors import SlackApiError

# When using Bolt, you can use either `app.client` or the `client` passed to listeners.
client = WebClient(token=os.environ.get("SLACK_BOT_TOKEN"))
# Channel ID can contain IM etc. See https://api.slack.com/methods/chat.postMessage#channels
# right click on channel, copy the link and extract the last part
# channel_id = "C020D8AMHFT"  # channel #exp-notifier
# chnan # channel_id = "C020D8AMHFT"
user_id = "D01NZQPN2RY"

logger = logging.getLogger(__name__)

try:
    # Call the chat.postMessage method using the WebClient
    result = client.conversations_open(users=[user_id])
    result['channel']['id']
    # result = client.chat_postMessage(
    #     # channel='#exp-notifier', 
    #     # channel='@Ondra',  # does not work
    #     channel=channel_id,
    #     text="Hello world from Bolt Slack simple wrapper - channel name"
    # )
    logger.info(result)

except SlackApiError as e:
    logger.error(f"Error posting message: {e}")



#!/usr/bin/env python3
from setuptools import find_packages, setup
from pathlib import Path

project_root = Path(__file__).parent
install_requires = (project_root / 'requirements.txt').read_text().splitlines()

setup(
    name='exp-notifier',
    version='0.0.2',
    python_requires='>=3.6.0',
    description='Notifcation from experiments to you devices (via slack)',
    long_description=(project_root / 'README.md').read_text(),
    long_description_content_type="text/markdown",
    author='Ondrej Platek',
    author_email='ondrej.platek@seznam.cz',
    license='Apache-2.0 License',
    url='https://github.com/oplatek/exp-notifier',
    donwload_url='https://github.com/oplatek/exp-notifier/archive/refs/tags/0.0.2.tar.gz',
    packages=find_packages(),
    scripts=['notifier/bin/ntf'],
    install_requires=install_requires,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: System :: Logging',
        'Topic :: System :: Networking :: Monitoring',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
